import subprocess

# cheap python 2/3 compatability
try:
    unicode
except NameError:
    unicode = str

def _divider(divider):
    return {
        u'contents': divider,
        u'highlight_groups': ['window_status']
    }

def _segment(num_mails, search):
    try:
        icon = search['icon']
        if icon != u"":
            icon += u" "
    except KeyError:
        icon = u"\u2709 "
    return {
                u'contents': u"{0}{1}".format(icon, unicode(num_mails, "utf-8")),
                u'highlight_groups': ['window_status'],
    }

def _get_num_mails(pl, search):
    proc = subprocess.Popen(['notmuch', 'count', search], stdout=subprocess.PIPE)
    num_mails, err = proc.communicate()
    if err is None:
        return num_mails.strip()
    pl.error("Could not get number of mails for search '{0}' due to error: {1}".format(search, err))
    return "-"

def _intersperse_dividers(segments, divider):
    for segment in segments:
        yield segment
        yield _divider(divider)

def notmuch(pl, searches=[{'search': 'tag:unread'}], divider=u" "):
    u"""Return number of mails matching notmuch search strings.

    Args:
        searches (list of dict):
            Each dictionary must contain the key "search" which will be used as the
            final part of a "notmuch count" query. A dictionary may contain an
            "icon" key holding the (unicode) icon used to mark the number mails.
            Defaults to "\u2709". Set to empty string to deactivate.
        divider (str):
            String used to divide individual mail counts. May be used as an
            alternative to `draw_inner_divider` configuration option. Can be nicely
            combined with the `before` and `after` configuration options.
    """

    num_mails = [_get_num_mails(pl, search['search']) for search in searches]
    segments = [_segment(num, search) for num, search in zip(num_mails, searches)]
    interspersed = [segment for segment in _intersperse_dividers(segments, divider)]
    interspersed.pop()  # Should be handled by intersperse function...
    return interspersed



from setuptools import setup
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='powerline_notmuch',
    version='0.1',
    description='Query your notmuch database from powerline',
    long_description=long_description,
    url='https://github.com/yggdr/powerline_notmuch',
    author='Konstantin Schukraft',
    author_email='konstantin@schukraft.org',
    license='ISC',
    classifiers=[
            'Development Status :: 4 - Beta',
            'Environment :: Console',
            'Intended Audience :: End Users/Desktop',
            'License :: OSI Approved :: ISC License (ISCL)',
            'Operating System :: POSIX',
            'Operating System :: Unix',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.6',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.3',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Topic :: Communications :: Email'
    ],
    keywords='powerline notmuch email',
    platforms='any',
    packages=['powerline_notmuch'],
)
